package main

import (
	"flag"
	"fmt"
	"os"

	"github.com/confluentinc/confluent-kafka-go/kafka"
)

var (
	broker    *string
	groupId   *int
	topic     *string
	partition *int
	timeout   *int
	newAPI    *bool
)

func init() {
	broker = flag.String("broker", "localhost:9092", "kafka broker list, e.g: broker1:port1,broker2:port2")
	groupId = flag.Int("groupId", 0, "kafka group Id")
	topic = flag.String("topic", "", "kafka topic")
	partition = flag.Int("partitionId", 0, "kafka partition Id")
	timeout = flag.Int("timeout", 2, "kafka query timeout value")
	newAPI = flag.Bool("newAPI", false, "true to QueryWatermarkOffsets; false to OffsetsForTimes")
}

func main() {
	flag.Parse()
	fmt.Printf("broker [%v] groupId [%v]\r\n", *broker, *groupId)
	fmt.Printf("topic [%v] partition [%v] timeout [%v]\r\n", *topic, *partition, *timeout)
	fmt.Printf("newAPI [%v]", *newAPI)
	configMap := &kafka.ConfigMap{
		"bootstrap.servers":  *broker,
		"group.id":           *groupId,
		"session.timeout.ms": 10000,
	}
	consumer, err := kafka.NewConsumer(configMap)
	if err != nil {
		fmt.Printf("new consumer err %v", err)
		os.Exit(1)
	}

	if *newAPI {
		low, high, err1 := consumer.QueryWatermarkOffsets(*topic, int32(*partition), *timeout)
		fmt.Printf("low %v high %v err %v\r\n", low, high, err1)
	} else {
		var earliest []kafka.TopicPartition

		earliest = append(earliest, kafka.TopicPartition{
			Topic:     topic,
			Partition: int32(*partition),
			Offset:    kafka.OffsetBeginning,
		})
		earliest, err = consumer.OffsetsForTimes(earliest, *timeout)
		fmt.Printf("earliest %#v err %v", earliest, err)

		var latest []kafka.TopicPartition

		latest = append(latest, kafka.TopicPartition{
			Topic:     topic,
			Partition: int32(*partition),
			Offset:    kafka.OffsetEnd,
		})

		latest, err = consumer.OffsetsForTimes(latest, *timeout)
		fmt.Printf("latest %#v err %v", latest, err)

	}
}
